@@ -1,6 +1,19 @@
 #' Probability of Direction (pd)
 #'
-#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\% and 100\% (\emph{i.e.}, \code{0.5} and \code{1}) and can be interpreted as the probability (expressed in percentage) that a parameter (described by its posterior distribution) is strictly positive or negative (whichever is the most probable). It is mathematically defined as the proportion of the posterior distribution that is of the median's sign. Although differently expressed, this index is fairly similar (\emph{i.e.}, is strongly correlated) to the frequentist \strong{p-value}. In some rare situations, especially when using when using model averaged posteriors (see \code{\link{weighted_posteriors}} or \code{brms::posterior_average}), this value may be lower than 0.5.
+#' Compute the \strong{Probability of Direction} (\strong{\emph{pd}}, also known
+#' as the Maximum Probability of Effect - \emph{MPE}). It varies between 50\%
+#' and 100\% (\emph{i.e.}, \code{0.5} and \code{1}) and can be interpreted as
+#' the probability (expressed in percentage) that a parameter (described by its
+#' posterior distribution) is strictly positive or negative (whichever is the
+#' most probable). It is mathematically defined as the proportion of the
+#' posterior distribution that is of the median's sign. Although differently
+#' expressed, this index is fairly similar (\emph{i.e.}, is strongly correlated)
+#' to the frequentist \strong{p-value}.
+#' \cr\cr
+#' Note that in some (rare) cases, especially when used with model averaged
+#' posteriors (see \code{\link{weighted_posteriors}} or
+#' \code{brms::posterior_average}), \code{pd} can be smaller than \code{0.5},
+#' reflecting high credibility of \code{0}.
 #'
 #' @param x Vector representing a posterior distribution. Can also be a Bayesian model (\code{stanreg}, \code{brmsfit} or \code{BayesFactor}).
 #' @param method Can be \code{"direct"} or one of methods of \link[=estimate_density]{density estimation}, such as \code{"kernel"}, \code{"logspline"} or \code{"KernSmooth"}. If \code{"direct"} (default), the computation is based on the raw ratio of samples superior and inferior to 0. Else, the result is based on the \link[=auc]{Area under the Curve (AUC)} of the estimated \link[=estimate_density]{density} function.
@@ -27,7 +40,14 @@
 #' \strong{Limitations:} Limited information favoring the null hypothesis.
 #' }
 #'
-#' @return Values between 0.5 and 1 corresponding to the probability of direction (pd). In some rare situations, especially when using when using model averaged posteriors (see \code{brms::weighted_posteriors} or \code{brms::posterior_average}), this value may be lower than 0.5.
+#' @return
+#' Values between 0.5 and 1 corresponding to the probability of direction (pd).
+#' \cr\cr
+#' Note that in some (rare) cases, especially when used with model averaged
+#' posteriors (see \code{\link{weighted_posteriors}} or
+#' \code{brms::posterior_average}), \code{pd} can be smaller than \code{0.5},
+#' reflecting high credibility of \code{0}. To detect such cases, the
+#' \code{method = "direct"} must be used.
 #'
 #' @seealso \code{\link{pd_to_p}} to convert between Probability of Direction (pd) and p-value.
 #'
@@ -187,12 +207,16 @@ p_direction.bayesQR <- function(x, method = "direct", ...) {
 #' @rdname p_direction
 #' @export
 p_direction.emmGrid <- function(x, method = "direct", ...) {
-  xdf <- .clean_emmeans_draws(x)
+  xdf <- insight::get_parameters(x)
+
   out <- p_direction(xdf, method = method, ...)
   attr(out, "object_name") <- deparse(substitute(x), width.cutoff = 500)
   out
 }
 
+#' @export
+p_direction.emm_list <- p_direction.emmGrid
+
 #' @importFrom insight get_parameters
 #' @keywords internal
 .p_direction_models <- function(x, effects, component, parameters, method = "direct", ...) {
@@ -240,7 +264,8 @@ p_direction.stanreg <- function(x, effects = c("fixed", "random", "all"), parame
 
   out <- .prepare_output(
     p_direction(insight::get_parameters(x, effects = effects, parameters = parameters), method = method, ...),
-    insight::clean_parameters(x)
+    insight::clean_parameters(x),
+    inherits(x, "stanmvreg")
   )
 
   class(out) <- unique(c("p_direction", "see_p_direction", class(out)))
